Crate cellulars

Crate cellulars 

A very fast, extensible CPM implementation.

Getting started:

A minimal CPM implementation can be found in the basic example, which should give you an idea of how to get started.

Also check out the other examples.

Alternatively, we provide a template repo with additional features that do not fit in the library to reduce boilerplate. These include a command line tool, a parameter parser and automatic data-write/backup.

Modules

base
Bundle of base structs used to build complex behaviour via composition.
cell_container
Contains logic associated with CellContainer.
constants
Contains constants.
empty_cell
Contains logic associated with EmptyCell.
io
Bundle of submodules used for IO operations.
lattice
Contains logic associated with Lattice.
positional
Bundle of submodules that relate to positioning in space.
prelude
Prelude containing commonly used items.
spin
Contains logic associated with Spin.
static_adhesion
Contains logic associated with StaticAdhesion.
symmetric_table
Contains logic associated with SymmetricTable.
traits
Bundle of traits that implement complex behavior on composite types containing base types.

Macros

cell_container
Initializes a CellContainer with EmptyCells.